==> unit-1.0.53-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableUpdateDateItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableUpdateDateItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _25_58_1472241048 _25_58_1472241048;
	public TasksTableUpdateDateItem._25_58_1472241048. UpdateDate updateDate;

    public TasksTableUpdateDateItem(UnitBox box) {
        super(box);
        id("a_1592467484");
    }

    @Override
	public void init() {
		super.init();
		if (_25_58_1472241048 == null) _25_58_1472241048 = register(new _25_58_1472241048(box()).<_25_58_1472241048>id("a634191047").owner(TasksTableUpdateDateItem.this));
		if (_25_58_1472241048 != null) updateDate = _25_58_1472241048.updateDate;
	}

	public class _25_58_1472241048 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableUpdateDateItem._25_58_1472241048. UpdateDate updateDate;

		public _25_58_1472241048(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (updateDate == null) updateDate = register(new UpdateDate(box()).<UpdateDate>id("a_474320152").owner(TasksTableUpdateDateItem.this));
		}

		public class UpdateDate extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public UpdateDate(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableUpdateDateItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableUpdateDateItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _25_58_1472241048 _25_58_1472241048;
	public TasksTableUpdateDateItem._25_58_1472241048. UpdateDate updateDate;

    public TasksTableUpdateDateItem(UnitBox box) {
        super(box);
        id("a_1592467484");
    }

    @Override
	public void init() {
		super.init();
		if (_25_58_1472241048 == null) _25_58_1472241048 = register(new _25_58_1472241048(box()).<_25_58_1472241048>id("a634191047").owner(TasksTableUpdateDateItem.this));
		if (_25_58_1472241048 != null) updateDate = _25_58_1472241048.updateDate;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_25_58_1472241048 != null) _25_58_1472241048.unregister();
	}

	public class _25_58_1472241048 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableUpdateDateItem._25_58_1472241048. UpdateDate updateDate;

		public _25_58_1472241048(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (updateDate == null) updateDate = register(new UpdateDate(box()).<UpdateDate>id("a_474320152").owner(TasksTableUpdateDateItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (updateDate != null) updateDate.unregister();
		}

		public class UpdateDate extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public UpdateDate(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
